@@ -22,7 +22,6 @@ from flytekit.core.data_persistence import FileAccessProvider
 from flytekit.core.type_engine import TypeEngine
 from flytekit.core.workflow import PythonFunctionWorkflow, WorkflowBase
 from flytekit.loggers import cli_logger
-from flytekit.models import literals
 from flytekit.models.interface import Variable
 from flytekit.models.literals import Blob, BlobMetadata, Primitive
 from flytekit.models.types import LiteralType, SimpleType
@@ -158,9 +157,6 @@ class FlyteLiteralConverter(object):
             self._converter = self.SIMPLE_TYPE_CONVERTER[SimpleType.STRING]
             self._click_type = click.Choice(self._literal_type.enum_type.values)
 
-        if self._literal_type.structured_dataset_type:
-            self._click_type = DirParamType()
-
         if self._literal_type.collection_type or self._literal_type.map_value_type:
             self._click_type = JsonParamType()
             if self._literal_type.collection_type:
@@ -196,25 +192,6 @@ class FlyteLiteralConverter(object):
 
         return uri
 
-    def convert_to_structured_dataset(
-        self, ctx: typing.Optional[click.Context], param: typing.Optional[click.Parameter], value: Directory
-    ) -> Literal:
-
-        uri = self.get_uri_for_dir(value, "00000.parquet")
-
-        lit = Literal(
-            scalar=Scalar(
-                structured_dataset=literals.StructuredDataset(
-                    uri=uri,
-                    metadata=literals.StructuredDatasetMetadata(
-                        structured_dataset_type=self._literal_type.structured_dataset_type
-                    ),
-                ),
-            ),
-        )
-
-        return lit
-
     def convert_to_blob(
         self,
         ctx: typing.Optional[click.Context],
@@ -246,14 +223,12 @@ class FlyteLiteralConverter(object):
     def convert_to_literal(
         self, ctx: typing.Optional[click.Context], param: typing.Optional[click.Parameter], value: typing.Any
     ) -> Literal:
-        if self._literal_type.structured_dataset_type:
-            return self.convert_to_structured_dataset(ctx, param, value)
 
         if self._literal_type.blob:
             return self.convert_to_blob(ctx, param, value)
 
         if self._literal_type.collection_type or self._literal_type.map_value_type:
-            # TODO Does not support nested flytefile, flyteschema types
+            # TODO Does not support nested flytefile types
             v = json.loads(value)
             if self._literal_type.collection_type and not isinstance(v, list):
                 raise click.BadParameter(f"Expected json list '[...]', parsed value is {type(v)}")
@@ -270,9 +245,6 @@ class FlyteLiteralConverter(object):
                 return TypeEngine.to_literal(self._flyte_ctx, o, self._python_type, self._literal_type)
             return Literal(scalar=self._converter.convert(value, self._python_type))
 
-        if self._literal_type.schema:
-            raise DeprecationWarning("Schema Types are not supported in pyflyte run. Use StructuredDataset instead.")
-
         raise NotImplementedError(
             f"CLI parsing is not available for Python Type:`{self._python_type}`, LiteralType:`{self._literal_type}`."
         )
@@ -466,10 +438,6 @@ def run_command(ctx: click.Context, wf_entity: PythonFunctionWorkflow):
 
         remote = ctx.obj[FLYTE_REMOTE_INSTANCE_KEY]
 
-        # StructuredDatasetTransformerEngine.register(
-        #     PandasToParquetDataProxyEncodingHandler(get_upload_url_fn), default_for_type=True
-        # )
-
         wf = remote.register_script(
             wf_entity,
             project=project,
