@@ -80,7 +80,6 @@ import datetime
 import enum
 import gzip
 import os
-import pathlib
 import re
 import tempfile
 import typing
@@ -496,9 +495,9 @@ class DataConfig(object):
     All DataPersistence plugins are passed all DataConfig and the plugin should correctly use the right config
     """
 
-    s3: S3Config = S3Config()
-    gcs: GCSConfig = GCSConfig()
-    latch: LatchConfig = LatchConfig()
+    s3: S3Config = field(default_factory=lambda: S3Config())
+    gcs: GCSConfig = field(default_factory=lambda: GCSConfig())
+    latch: LatchConfig = field(default_factory=lambda: LatchConfig())
 
     @classmethod
     def auto(cls, config_file: typing.Union[str, ConfigFile] = None) -> DataConfig:
