@@ -8,6 +8,7 @@ class PythonVersion(enum.Enum):
     PYTHON_3_8 = (3, 8)
     PYTHON_3_9 = (3, 9)
     PYTHON_3_10 = (3, 10)
+    PYTHON_3_11 = (3, 11)
 
 
 class DefaultImages(object):
@@ -20,6 +21,7 @@ class DefaultImages(object):
         PythonVersion.PYTHON_3_8: "ghcr.io/flyteorg/flytekit:py3.8-",
         PythonVersion.PYTHON_3_9: "ghcr.io/flyteorg/flytekit:py3.9-",
         PythonVersion.PYTHON_3_10: "ghcr.io/flyteorg/flytekit:py3.10-",
+        PythonVersion.PYTHON_3_11: "ghcr.io/flyteorg/flytekit:py3.11-",
     }
 
     @classmethod
