@@ -82,7 +82,6 @@ class ExecutionParameters(object):
         attrs: typing.Dict[str, typing.Any]
         working_dir: typing.Union[os.PathLike, utils.AutoDeletingTempDir]
         checkpoint: typing.Optional[Checkpoint]
-        decks: List[flytekit.Deck]
         raw_output_prefix: str
 
         def __init__(self, current: typing.Optional[ExecutionParameters] = None):
@@ -92,7 +91,6 @@ class ExecutionParameters(object):
             self.execution_id = current.execution_id if current else None
             self.logging = current.logging if current else None
             self.checkpoint = current._checkpoint if current else None
-            self.decks = current._decks if current else []
             self.attrs = current._attrs if current else {}
             self.raw_output_prefix = current.raw_output_prefix if current else None
 
@@ -110,7 +108,6 @@ class ExecutionParameters(object):
                 execution_id=self.execution_id,
                 logging=self.logging,
                 checkpoint=self.checkpoint,
-                decks=self.decks,
                 raw_output_prefix=self.raw_output_prefix,
                 **self.attrs,
             )
@@ -145,7 +142,6 @@ class ExecutionParameters(object):
         logging,
         raw_output_prefix,
         checkpoint=None,
-        decks=None,
         **kwargs,
     ):
         """
@@ -157,8 +153,6 @@ class ExecutionParameters(object):
             logging: handle to logging
             checkpoint: Checkpoint Handle to the configured checkpoint system
         """
-        if decks is None:
-            decks = []
         self._stats = stats
         self._execution_date = execution_date
         self._working_directory = tmp_dir
@@ -170,7 +164,6 @@ class ExecutionParameters(object):
         # It is safe to recreate the Secrets Manager
         self._secrets_manager = SecretsManager()
         self._checkpoint = checkpoint
-        self._decks = decks
 
     @property
     def stats(self) -> taggable.TaggableStats:
@@ -238,19 +231,6 @@ class ExecutionParameters(object):
             raise NotImplementedError("Checkpointing is not available, please check the version of the platform.")
         return self._checkpoint
 
-    @property
-    def decks(self) -> typing.List:
-        """
-        A list of decks of the tasks, and it will be rendered to a html at the end of the task execution.
-        """
-        return self._decks
-
-    @property
-    def default_deck(self) -> "Deck":
-        from flytekit import Deck
-
-        return Deck("default")
-
     def __getattr__(self, attr_name: str) -> typing.Any:
         """
         This houses certain task specific context. For example in Spark, it houses the SparkSession, etc
@@ -792,7 +772,6 @@ class FlyteContextManager(object):
             logging=user_space_logger,
             tmp_dir=user_space_path,
             raw_output_prefix=default_context.file_access._raw_output_prefix,
-            decks=[],
         )
 
         default_context = default_context.with_execution_state(
