@@ -91,7 +91,6 @@ def task(
     execution_mode: Optional[PythonFunctionTask.ExecutionBehavior] = PythonFunctionTask.ExecutionBehavior.DEFAULT,
     dockerfile: Optional[Path] = None,
     task_resolver: Optional[TaskResolverMixin] = None,
-    disable_deck: bool = False,
 ) -> Union[Callable, PythonFunctionTask]:
     """
     This is the core decorator to use for any task type in flytekit.
@@ -180,7 +179,6 @@ def task(
                      may change based on the backend provider.
     :param execution_mode: This is mainly for internal use. Please ignore. It is filled in automatically.
     :param task_resolver: Provide a custom task resolver.
-    :param disable_deck: If true, this task will not output deck html file
     """
 
     def wrapper(fn) -> PythonFunctionTask:
@@ -206,7 +204,6 @@ def task(
             execution_mode=execution_mode,
             dockerfile_path=dockerfile,
             task_resolver=task_resolver,
-            disable_deck=disable_deck,
         )
         update_wrapper(task_instance, fn)
         return task_instance
