@@ -8,7 +8,6 @@ import inspect
 import json as _json
 import mimetypes
 import textwrap
-import traceback
 import typing
 import warnings
 from abc import ABC, abstractmethod
@@ -50,8 +49,6 @@ from flytekit.models.literals import (
     Record,
     RecordField,
     Scalar,
-    Schema,
-    StructuredDatasetMetadata,
     Union,
     Void,
 )
@@ -60,7 +57,6 @@ from flytekit.models.types import (
     RecordFieldType,
     RecordType,
     SimpleType,
-    StructuredDatasetType,
     TypeStructure,
     UnionType,
 )
@@ -518,14 +514,10 @@ class DataclassTransformer(TypeTransformer[object]):
     def _flyte_type_superhack(self, v: T, field_type: Type[T], schema, defs):
         from flytekit.types.directory.types import FlyteDirectory
         from flytekit.types.file import FlyteFile
-        from flytekit.types.schema.types import FlyteSchema
-        from flytekit.types.structured.structured_dataset import StructuredDataset
 
         if inspect.isclass(field_type) and (
-            issubclass(field_type, FlyteSchema)
-            or issubclass(field_type, FlyteFile)
+            issubclass(field_type, FlyteFile)
             or issubclass(field_type, FlyteDirectory)
-            or issubclass(field_type, StructuredDataset)
         ):
             lv = TypeEngine.to_literal(FlyteContext.current_context(), v, field_type, None)
             # dataclass_json package will extract the "path" from FlyteFile, FlyteDirectory, and write it to a
@@ -536,12 +528,7 @@ class DataclassTransformer(TypeTransformer[object]):
             # set, then the real uri in the literal should be the remote source, not the path (which may be an
             # auto-generated random local path). To be sure we're writing the right path to the json, use the uri
             # as determined by the transformer.
-            if issubclass(field_type, FlyteFile) or issubclass(field_type, FlyteDirectory):
-                return field_type(path=lv.scalar.blob.uri)
-            elif issubclass(field_type, StructuredDataset):
-                return field_type(
-                    uri=lv.scalar.structured_dataset.uri,
-                )
+            return field_type(path=lv.scalar.blob.uri)
         elif dataclasses.is_dataclass(field_type):
             self._dataclass_superhack(v, field_type, defs[schema["$ref"][len("#/definitions/") :]], defs)
         elif get_origin(field_type) is typing.Union:
@@ -582,8 +569,6 @@ class DataclassTransformer(TypeTransformer[object]):
     def _deserialize_superhack(self, python_val, expected_python_type: Type):
         from flytekit.types.directory.types import FlyteDirectory, FlyteDirToMultipartBlobTransformer
         from flytekit.types.file.file import FlyteFile, FlyteFilePathTransformer
-        from flytekit.types.schema.types import FlyteSchema, FlyteSchemaTransformer
-        from flytekit.types.structured.structured_dataset import StructuredDataset, StructuredDatasetTransformerEngine
 
         if dataclasses.is_dataclass(expected_python_type) and isinstance(python_val, dict):
             return self._dataclass_deserialize_superhack(
@@ -601,16 +586,7 @@ class DataclassTransformer(TypeTransformer[object]):
             raise TypeTransformerFailedError(f"could not find a suitable instantiation for {expected_python_type}")
 
         if inspect.isclass(expected_python_type):
-            if issubclass(expected_python_type, FlyteSchema):
-                t = FlyteSchemaTransformer()
-                return t.to_python_value(
-                    FlyteContext.current_context(),
-                    Literal(
-                        scalar=Scalar(schema=Schema(python_val.remote_path, t._get_schema_type(expected_python_type)))
-                    ),
-                    expected_python_type,
-                )
-            elif issubclass(expected_python_type, FlyteFile):
+            if issubclass(expected_python_type, FlyteFile):
                 return TypeEngine.to_python_value(
                     FlyteContext.current_context(),
                     Literal(
@@ -644,21 +620,6 @@ class DataclassTransformer(TypeTransformer[object]):
                     ),
                     expected_python_type,
                 )
-            elif issubclass(expected_python_type, StructuredDataset):
-                return StructuredDatasetTransformerEngine().to_python_value(
-                    FlyteContext.current_context(),
-                    Literal(
-                        scalar=Scalar(
-                            structured_dataset=StructuredDataset(
-                                metadata=StructuredDatasetMetadata(
-                                    structured_dataset_type=StructuredDatasetType(format=python_val.file_format)
-                                ),
-                                uri=python_val.uri,
-                            )
-                        )
-                    ),
-                    expected_python_type,
-                )
 
         return python_val
 
@@ -983,21 +944,6 @@ class TypeEngine(typing.Generic[T]):
         transformer = cls.get_transformer(expected_python_type)
         return transformer.to_python_value(ctx, lv, expected_python_type)
 
-    @classmethod
-    def to_html(cls, ctx: FlyteContext, python_val: typing.Any, expected_python_type: Type[T]) -> str:
-        transformer = cls.get_transformer(expected_python_type)
-        if get_origin(expected_python_type) is Annotated:
-            expected_python_type, *annotate_args = get_args(expected_python_type)
-            from flytekit.deck.renderer import Renderable
-
-            for arg in annotate_args:
-                if isinstance(arg, Renderable):
-                    return arg.to_html(python_val)
-        try:
-            return transformer.to_html(ctx, python_val, expected_python_type)
-        except:
-            return "unable to convert value to html string"
-
     @classmethod
     def named_tuple_to_variable_map(cls, t: typing.NamedTuple) -> _interface_models.VariableMap:
         """
@@ -1185,39 +1131,6 @@ def _are_types_castable(upstream: LiteralType, downstream: LiteralType) -> bool:
 
         return _are_types_castable(upstream.map_value_type, downstream.map_value_type)
 
-    # TODO: Structured dataset type matching requires that downstream structured datasets
-    # are a strict sub-set of the upstream structured dataset.
-    if upstream.structured_dataset_type is not None:
-        if downstream.structured_dataset_type is None:
-            return False
-
-        usdt = upstream.structured_dataset_type
-        dsdt = downstream.structured_dataset_type
-
-        if usdt.format != dsdt.format:
-            return False
-
-        if usdt.external_schema_type != dsdt.external_schema_type:
-            return False
-
-        if usdt.external_schema_bytes != dsdt.external_schema_bytes:
-            return False
-
-        ucols = usdt.columns
-        dcols = dsdt.columns
-
-        if len(ucols) != len(dcols):
-            return False
-
-        for u, d in zip(ucols, dcols):
-            if u.name != d.name:
-                return False
-
-            if not _are_types_castable(u.literal_type, d.literal_type):
-                return False
-
-        return True
-
     if upstream.union_type is not None:
         # for each upstream variant, there must be a compatible type downstream
         for v in upstream.union_type.variants:
