@@ -572,8 +572,12 @@ class PythonFunctionWorkflow(WorkflowBase, ClassStorageTaskResolver):
         metadata: Optional[WorkflowMetadata],
         default_metadata: Optional[WorkflowMetadataDefaults],
         docstring: Docstring = None,
+        wf_name_override: Optional[str] = None,
     ):
         name, _, _, _ = extract_task_module(workflow_function)
+        if wf_name_override is not None:
+            name = wf_name_override
+
         self._workflow_function = workflow_function
         native_interface = transform_function_to_interface(workflow_function, docstring=docstring)
 
@@ -690,6 +694,7 @@ def workflow(
     _workflow_function=None,
     failure_policy: Optional[WorkflowFailurePolicy] = None,
     interruptible: bool = False,
+    wf_name_override: Optional[str] = None,
 ):
     """
     This decorator declares a function to be a Flyte workflow. Workflows are declarative entities that construct a DAG
@@ -730,6 +735,7 @@ def workflow(
             metadata=workflow_metadata,
             default_metadata=workflow_metadata_defaults,
             docstring=Docstring(callable_=fn),
+            wf_name_override=wf_name_override,
         )
         workflow_instance.compile()
         update_wrapper(workflow_instance, fn)
