@@ -1,4 +1,8 @@
+import os
+import platform
+import sys
 from sys import exc_info as _exc_info
+from textwrap import dedent, indent
 from traceback import format_tb as _format_tb
 
 from wrapt import decorator as _decorator
@@ -9,6 +13,14 @@ from flytekit.exceptions import user as _user_exceptions
 from flytekit.models.core import errors as _error_model
 
 
+def get_pkg_version():
+    try:
+        from importlib import metadata
+    except ImportError:
+        import importlib_metadata as metadata
+    return metadata.version("lytekit")
+
+
 class FlyteScopedException(Exception):
     def __init__(self, context, exc_type, exc_value, exc_tb, top_trim=0, bottom_trim=0, kind=None):
         self._exc_type = exc_type
@@ -34,13 +46,22 @@ class FlyteScopedException(Exception):
             tb = tb.tb_next
         limit = max(0, limit - self._bottom_trim)
 
-        lines = _format_tb(top_tb, limit=limit)
-        lines = [line.rstrip() for line in lines]
-        lines = "\n".join(lines).split("\n")
-        traceback_str = "\n    ".join([""] + lines)
+        lines = "".join(_format_tb(top_tb, limit=limit)).replace("  ", "    ")
+        traceback_str = indent(lines, "    " * 3)
+        py_version = sys.version.replace("\n", "")
 
-        format_str = "Traceback (most recent call last):\n" "{traceback}\n" "\n" "Message:\n" "\n" "    {message}"
-        return format_str.format(traceback=traceback_str, message=str(self.value))
+        return dedent(f"""
+            Traceback (most recent call last):
+{traceback_str}
+
+            Message: {self.value}
+
+            Metadata:
+                FlyteKit Version: {get_pkg_version()}
+                Python Version: {py_version}
+                Platform: {platform.platform()}
+                OS: {os.name}, {platform.version()}
+        """)
 
     def __str__(self):
         return str(self.value)
