@@ -10,8 +10,6 @@ from flytekit.models import common as _common
 from flytekit.models.core import types as _core_types
 from flytekit.models.types import LiteralType as _LiteralType
 from flytekit.models.types import OutputReference as _OutputReference
-from flytekit.models.types import SchemaType as _SchemaType
-from flytekit.models.types import StructuredDatasetType
 
 
 class RetryStrategy(_common.FlyteIdlEntity):
@@ -557,46 +555,6 @@ class Binding(_common.FlyteIdlEntity):
         return cls(pb2_object.var, BindingData.from_flyte_idl(pb2_object.binding))
 
 
-class Schema(_common.FlyteIdlEntity):
-    def __init__(self, uri, type):
-        """
-        A strongly typed schema that defines the interface of data retrieved from the underlying storage medium.
-
-        :param Text uri:
-        :param flytekit.models.types.SchemaType type:
-        """
-        self._uri = uri
-        self._type = type
-
-    @property
-    def uri(self):
-        """
-        :rtype: Text
-        """
-        return self._uri
-
-    @property
-    def type(self):
-        """
-        :rtype: flytekit.models.types.SchemaType
-        """
-        return self._type
-
-    def to_flyte_idl(self):
-        """
-        :rtype: flyteidl.core.literals_pb2.Schema
-        """
-        return _literals_pb2.Schema(uri=self.uri, type=self.type.to_flyte_idl())
-
-    @classmethod
-    def from_flyte_idl(cls, pb2_object):
-        """
-        :param flyteidl.core.literals_pb2.Schema pb2_object:
-        :rtype: Schema
-        """
-        return cls(uri=pb2_object.uri, type=_SchemaType.from_flyte_idl(pb2_object.type))
-
-
 class Union(_common.FlyteIdlEntity):
     def __init__(self, value, stored_type):
         """
@@ -676,54 +634,6 @@ class Record(_common.FlyteIdlEntity):
         return cls(fields=[RecordField.from_flyte_idl(x) for x in proto.fields])
 
 
-class StructuredDatasetMetadata(_common.FlyteIdlEntity):
-    def __init__(self, structured_dataset_type: Optional[StructuredDatasetType] = None):
-        self._structured_dataset_type = structured_dataset_type
-
-    @property
-    def structured_dataset_type(self) -> StructuredDatasetType:
-        return self._structured_dataset_type
-
-    def to_flyte_idl(self) -> _literals_pb2.StructuredDatasetMetadata:
-        return _literals_pb2.StructuredDatasetMetadata(
-            structured_dataset_type=self.structured_dataset_type.to_flyte_idl()
-            if self._structured_dataset_type
-            else None,
-        )
-
-    @classmethod
-    def from_flyte_idl(cls, pb2_object: _literals_pb2.StructuredDatasetMetadata) -> "StructuredDatasetMetadata":
-        return cls(
-            structured_dataset_type=StructuredDatasetType.from_flyte_idl(pb2_object.structured_dataset_type),
-        )
-
-
-class StructuredDataset(_common.FlyteIdlEntity):
-    def __init__(self, uri: str, metadata: Optional[StructuredDatasetMetadata] = None):
-        """
-        A strongly typed schema that defines the interface of data retrieved from the underlying storage medium.
-        """
-        self._uri = uri
-        self._metadata = metadata
-
-    @property
-    def uri(self) -> str:
-        return self._uri
-
-    @property
-    def metadata(self) -> StructuredDatasetMetadata:
-        return self._metadata
-
-    def to_flyte_idl(self) -> _literals_pb2.StructuredDataset:
-        return _literals_pb2.StructuredDataset(
-            uri=self.uri, metadata=self.metadata.to_flyte_idl() if self.metadata else None
-        )
-
-    @classmethod
-    def from_flyte_idl(cls, pb2_object: _literals_pb2.StructuredDataset) -> "StructuredDataset":
-        return cls(uri=pb2_object.uri, metadata=StructuredDatasetMetadata.from_flyte_idl(pb2_object.metadata))
-
-
 class LiteralCollection(_common.FlyteIdlEntity):
     def __init__(self, literals):
         """
@@ -789,12 +699,10 @@ class Scalar(_common.FlyteIdlEntity):
         primitive: Primitive = None,
         blob: Blob = None,
         binary: Binary = None,
-        schema: Schema = None,
         union: Union = None,
         none_type: Void = None,
         error=None,
         generic: Struct = None,
-        structured_dataset: StructuredDataset = None,
     ):
         """
         Scalar wrapper around Flyte types.  Only one can be specified.
@@ -806,18 +714,15 @@ class Scalar(_common.FlyteIdlEntity):
         :param Void none_type:
         :param error:
         :param google.protobuf.struct_pb2.Struct generic:
-        :param StructuredDataset structured_dataset:
         """
 
         self._primitive = primitive
         self._blob = blob
         self._binary = binary
-        self._schema = schema
         self._union = union
         self._none_type = none_type
         self._error = error
         self._generic = generic
-        self._structured_dataset = structured_dataset
 
     @property
     def primitive(self):
@@ -840,13 +745,6 @@ class Scalar(_common.FlyteIdlEntity):
         """
         return self._binary
 
-    @property
-    def schema(self):
-        """
-        :rtype: Schema
-        """
-        return self._schema
-
     @property
     def union(self):
         """
@@ -875,10 +773,6 @@ class Scalar(_common.FlyteIdlEntity):
         """
         return self._generic
 
-    @property
-    def structured_dataset(self) -> StructuredDataset:
-        return self._structured_dataset
-
     @property
     def value(self):
         """
@@ -889,12 +783,10 @@ class Scalar(_common.FlyteIdlEntity):
             self.primitive
             or self.blob
             or self.binary
-            or self.schema
             or self.union
             or self.none_type
             or self.error
             or self.generic
-            or self.structured_dataset
         )
 
     def to_flyte_idl(self):
@@ -905,12 +797,10 @@ class Scalar(_common.FlyteIdlEntity):
             primitive=self.primitive.to_flyte_idl() if self.primitive is not None else None,
             blob=self.blob.to_flyte_idl() if self.blob is not None else None,
             binary=self.binary.to_flyte_idl() if self.binary is not None else None,
-            schema=self.schema.to_flyte_idl() if self.schema is not None else None,
             union=self.union.to_flyte_idl() if self.union is not None else None,
             none_type=self.none_type.to_flyte_idl() if self.none_type is not None else None,
             error=self.error if self.error is not None else None,
             generic=self.generic,
-            structured_dataset=self.structured_dataset.to_flyte_idl() if self.structured_dataset is not None else None,
         )
 
     @classmethod
@@ -924,14 +814,10 @@ class Scalar(_common.FlyteIdlEntity):
             primitive=Primitive.from_flyte_idl(pb2_object.primitive) if pb2_object.HasField("primitive") else None,
             blob=Blob.from_flyte_idl(pb2_object.blob) if pb2_object.HasField("blob") else None,
             binary=Binary.from_flyte_idl(pb2_object.binary) if pb2_object.HasField("binary") else None,
-            schema=Schema.from_flyte_idl(pb2_object.schema) if pb2_object.HasField("schema") else None,
             union=Union.from_flyte_idl(pb2_object.union) if pb2_object.HasField("union") else None,
             none_type=Void.from_flyte_idl(pb2_object.none_type) if pb2_object.HasField("none_type") else None,
             error=pb2_object.error if pb2_object.HasField("error") else None,
             generic=pb2_object.generic if pb2_object.HasField("generic") else None,
-            structured_dataset=StructuredDataset.from_flyte_idl(pb2_object.structured_dataset)
-            if pb2_object.HasField("structured_dataset")
-            else None,
         )
 
 
